FAQ: Installation — Bombardier v1.00 documentation

### Navigation

- index
- next |
- previous |
- Bombardier v1.00 documentation »
- Bombardier documentation contents »
- Bombardier FAQ »

# FAQ: Installation

## How do I get started?

> 1. Download the code.
> 2. Install Bombardier Server (read the installation guide).
> 3. Walk through the tutorial.
> 4. Check out the rest of the documentation, and ask questions if you run into trouble.

## Can I use Bombardier with Python 3?

No, This hasn’t been tested at all.

### Navigation

- index
- next |
- previous |
- Bombardier v1.00 documentation »
- Bombardier documentation contents »
- Bombardier FAQ »